<?php declare(strict_types=1);

namespace App\DataFixtures;

use App\Entity\ItemExtra;
use App\Entity\MenuItem;
use App\Entity\MenuItemAlias;
use App\Entity\Vendor;
use Doctrine\Bundle\FixturesBundle\Fixture;
use Doctrine\Persistence\ObjectManager;
use Faker\Factory;
use Faker\Generator;
use Override;

use function random_int;
use function range;

final class AppFixture extends Fixture
{
    private Generator $faker;

    #[Override]
    public function load(ObjectManager $manager): void
    {
        $this->faker = Factory::create();

        foreach (range(0, 20) as $vendorCount) {
            $this->createVendorAndMenuItems($manager);
        }

        $manager->flush();
    }

    public function addMenuItemAliases(
        MenuItem $menuItem,
        ObjectManager $manager,
    ): void {
        $menuItemAliasOne = new MenuItemAlias;
        $menuItemAliasOne->setName($this->faker->word);
        $menuItem->addMenuItemAlias($menuItemAliasOne);
        $manager->persist($menuItemAliasOne);
        $menuItemAliasTwo = new MenuItemAlias;
        $menuItemAliasTwo->setName($this->faker->word);
        $menuItem->addMenuItemAlias($menuItemAliasTwo);
        $manager->persist($menuItemAliasTwo);
    }

    public function addMenuItemExtras(MenuItem $menuItem, ObjectManager $manager): void
    {
        foreach (range(0, random_int(0, 5)) as $dispose) {
            $itemExtra = new ItemExtra;
            $itemExtra->setName($this->faker->word);
            $menuItem->addItemExtra($itemExtra);
            $manager->persist($itemExtra);
        }
    }

    public function createMenuItem(Vendor $vendor, ObjectManager $manager): void
    {
        $menuItem = new MenuItem;
        $menuItem->setVendor($vendor);
        $menuItem->setPrice(random_int(500, 2000));
        $manager->persist($menuItem);
        $this->addMenuItemAliases($menuItem, $manager);
        $this->addMenuItemExtras($menuItem, $manager);
    }

    public function createVendorAndMenuItems(ObjectManager $manager): void
    {
        $vendor = new Vendor;
        $vendor->setName($this->faker->name);
        $manager->persist($vendor);

        foreach (range(0, 10) as $itemCount) {
            $this->createMenuItem($vendor, $manager);
        }
    }
}
